@@ -17,20 +17,20 @@ datasummary_df <- function(data,
                            escape = TRUE,
                            ...) {
 
+  settings_init(settings = list("function_called" = "datasummary_df"))
+
   sanitize_output(output) # before sanitize_escape
   sanitize_escape(escape) # after sanitize_output
+  sanity_align(align)
 
   checkmate::assert_data_frame(data)
 
-  notes <- escape_string(notes)
-  title <- escape_string(title)
-
   for (n in colnames(data)) {
     fmt <- sanitize_fmt(fmt)
     data[[n]] <- fmt(data[[n]])
   }
 
-  factory(data,
+  out <- factory(data,
           align = align,
           hrule = hrule,
           notes = notes,
@@ -40,4 +40,7 @@ datasummary_df <- function(data,
           add_columns = add_columns,
           ...)
 
+  settings_rm()
+  return(out)
+
 }
